.. _user:

################
Numpy User Guide
################

This guide explains how to make use of different features
of Numpy. For a detailed documentation about different functions
and classes, see :ref:`reference`.

.. warning::

   This "User Guide" is still very much work in progress; the material
   is not organized, and many aspects of Numpy are not covered.

   More documentation for Numpy can be found on the
   `scipy.org <http://www.scipy.org/Documentation>`__ website.

.. toctree::
   :maxdepth: 2

   howtofind
   basics
   performance
   misc
   c-info

